@@ -342,7 +342,7 @@ class LocalTransformerBlock(nn.Module):
         **kwargs
     ):
         super().__init__()
-        self.attn = LocalMHA(dim = dim, qk_rmsnorm = True, **kwargs)
+        self.attn = LocalMHA(dim = dim, qk_rmsnorm = True, use_xpos = True, **kwargs)
         self.ff = FeedForward(dim = dim)
 
     def forward(self, x):
@@ -424,6 +424,8 @@ class SoundStream(nn.Module):
 
         self.encoder_attn = nn.Sequential(*[LocalTransformerBlock(**attn_kwargs) for _ in range(attn_depth)]) if use_local_attn else None
 
+        self.num_quantizers = rq_num_quantizers
+
         self.rq = ResidualVQ(
             dim = codebook_dim,
             num_quantizers = rq_num_quantizers,
